@@ -10,8 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import print_function
-
 import argparse
 import distro
 import re
@@ -228,7 +226,7 @@ RDO_PKG_MAP = [
     SingleRule('libvirt-python', 'libvirt-python', py3pkg='libvirt-python3'),
     SingleRule('tempest-horizon', 'python-horizon-tests-tempest'),
     SingleRule('rtslib-fb', 'python-rtslib', py3pkg='python3-rtslib'),
-    SingleRule('PyYAML', 'python-yaml', py3pkg='python3-yaml'),
+    SingleRule('PyYAML', 'PyYAML', py3pkg='python3-PyYAML'),
     SingleRule('pyOpenSSL', 'python-pyOpenSSL', py3pkg='python3-pyOpenSSL'),
     SingleRule('semantic_version', 'python-semantic_version',
                py3pkg='python3-semantic_version'),
